==> gtkmm_0.9.15.orig.tar.gz: Gtk---0.9.15/examples/testme1.cc <==
#include <stdio.h>
#include <gtk--.h>

// Main idea of this test program is to test how connections work in gtk.
//
// It does not do anything too neat, just prints some dummy things to
// console.

class MyWin : public Gtk_Window
{
    Gtk_HBox box;
    Gtk_VBox vbox;
    Gtk_Frame frame;
    Gtk_Frame frame1;
    Gtk_Button b0,b1;
    Gtk_Tooltips btip;
    Gtk_Entry text;
    Gtk_ProgressBar bar;
    Gtk_Notebook book;
    Gtk_Label bm1,bm2,bm3;
    int num;
    
    // Connection-objects can be used for disconecting a connection.
    // it isnt necessary to know about these at all, they are here
    // for easier use of connect().
    Connection c1,c2,c3,c4;
    
public:  
    Signal1<GdkEventKey *> keyPressed;
    Signal1<gint> foo;
    Signal0 test;
    
private:
    
    void dohello(){ printf("Button pushed - number was %d\n",num);}
    void dohello_cb(void *)
    {
      printf("Button pushed_cb\n");}
    
    
    void keypress(GdkEventKey *event)
    { 
	// sending foo and keyPressed-signals.
	foo(10); keyPressed(event); 
	test();
	c1.disconnect(); // now we'll test disconnecting the connections.
	c2.disconnect();
	c3.disconnect();
	c4.disconnect();
	printf("Keypress was %d",event->keyval);
    }
    
public:
    virtual void doblah(gint a) { printf("Blah: %d",a); }
    void doblah_cb(gint a,void*) { printf("Blah_cb:%d ",a); }
    gint delete_event_impl(GdkEventAny*) { Gtk_Main::instance()->quit(); return 0; }  
    MyWin(gint num);
};

MyWin::MyWin(int num)
    : Gtk_Window(GTK_WINDOW_TOPLEVEL),
      box(true,0),
      vbox(true,0),
      frame("A1"),frame1("A2"),
      b0("The"),
      b1("\"Very sad life. Probably have very sad death. \nBut at least, there is symmetry.\""),
      bm1("Babylon5Quote#1"),bm2("Babylon5Quote#2"),bm3("\"May God stand between you and harm,\n in all the empty places where you must walk\""),
      num(num)
{
    // vbox
    add(&book);
    book.append_page(&frame,&bm1);
    book.append_page(&frame1,&bm2);
    book.show();
    frame.add(&vbox);
    vbox.add(&box);
    vbox.add(&bar);
    frame.show();
    frame1.show();
    frame1.add(&b1);
    box.show();
    bar.show();
    vbox.show();
    bar.update(0.35);
    
    box.pack_start(&bm3);
    
    // connect sig0 to c++ function
    connect_to_method(test,this,&dohello);
    connect_to_method(test,this,&dohello_cb,(void*)0);
    
    // connect c++ signal to c++ function from gtk--
    c3=connect_to_method(foo,this,&border_width);
    
    // connect c++ signal to user function
    c4=connect_to_method(foo,this,&doblah);
    c2=connect_to_method(foo,this,&doblah_cb,(void*)0);
    connect_to_method(b1.clicked,Gtk_Main::instance(),&Gtk_Main::quit);

    btip.set_tip(&b1,"Press here to quit","A");
    b0.show();
    b1.show();
    bm3.show();
}

static void staticfunction(GdkEventKey* a) {
    printf("Staticfunction called! %p\n",a);
}

static void staticfunction_cb(GdkEventKey* a,void *) {
    printf("Staticfunction-cb called! %p\n",a);
}

Gtk_Main *mainwidget=0;

static gint myquit() {
    printf("MYQUIT\n");
    mainwidget->quit();
    return 0;
}

int
main(int argc, char *argv[])
{
    Gtk_Main myapp(&argc, &argv);
    mainwidget=&myapp;
    MyWin mywin(5);
    
    
    mywin.set_title("Notice!");

    mywin.show();
    
    // connecting to static function
    connect_to_function(mywin.keyPressed,&staticfunction); 
    connect_to_function(mywin.keyPressed,&staticfunction_cb,(void*)0);
    
    myapp.run();
    return 0;
}

==> gtkmm_1.0.3.orig.tar.gz: Gtk---1.0.3/examples/testme1.cc <==
#include <stdio.h>
#include <gtk--.h>

// Main idea of this test program is to test how connections work in gtk.
//
// It does not do anything too neat, just prints some dummy things to
// console.

class MyWin : public Gtk_Window
{
    Gtk_HBox box;
    Gtk_VBox vbox;
    Gtk_Frame frame;
    Gtk_Frame frame1;
    Gtk_Button b0,b1;
    Gtk_Tooltips btip;
    Gtk_Entry text;
    Gtk_ProgressBar bar;
    Gtk_Notebook book;
    Gtk_Label bm1,bm2,bm3;
    int num;
    
    // Connection-objects can be used for disconecting a connection.
    // it isnt necessary to know about these at all, they are here
    // for easier use of connect().
    Connection c1,c2,c3,c4;
    
public:  
    Signal1<GdkEventKey *> keyPressed;
    Signal1<gint> foo;
    Signal0 test;
    
private:
    
    void dohello(){ printf("Button pushed - number was %d\n",num);}
    void dohello_cb(void *)
    {
      printf("Button pushed_cb\n");}
    
    
    void keypress(GdkEventKey *event)
    { 
	// sending foo and keyPressed-signals.
	foo(10); keyPressed(event); 
	test();
	c1.disconnect(); // now we'll test disconnecting the connections.
	c2.disconnect();
	c3.disconnect();
	c4.disconnect();
	printf("Keypress was %d",event->keyval);
    }
    
public:
    virtual void doblah(gint a) { printf("Blah: %d",a); }
    void doblah_cb(gint a,void*) { printf("Blah_cb:%d ",a); }
    gint delete_event_impl(GdkEventAny*) { Gtk_Main::instance()->quit(); return 0; }  
    MyWin(gint num);
};

MyWin::MyWin(int num)
    : Gtk_Window(GTK_WINDOW_TOPLEVEL),
      box(true,0),
      vbox(true,0),
      frame("A1"),frame1("A2"),
      b0("The"),
      b1("\"Very sad life. Probably have very sad death. \nBut at least, there is symmetry.\""),
      bm1("Babylon5Quote#1"),bm2("Babylon5Quote#2"),bm3("\"May God stand between you and harm,\n in all the empty places where you must walk\""),
      num(num)
{
    // vbox
    add(&book);
    book.append_page(frame,bm1);
    book.append_page(frame1,bm2);
    book.show();
    frame.add(&vbox);
    vbox.add(&box);
    vbox.add(&bar);
    frame.show();
    frame1.show();
    frame1.add(&b1);
    box.show();
    bar.show();
    vbox.show();
    bar.set_percentage(0.35);
    
    box.pack_start(bm3);
    
    // connect sig0 to c++ function
    connect_to_method(test,this,&dohello);
    connect_to_method(test,this,&dohello_cb,(void*)0);
    
    // connect c++ signal to c++ function from gtk--
    c3=connect_to_method(foo,this,&set_border_width);
    
    // connect c++ signal to user function
    c4=connect_to_method(foo,this,&doblah);
    c2=connect_to_method(foo,this,&doblah_cb,(void*)0);
    connect_to_method(b1.clicked,Gtk_Main::instance(),&Gtk_Main::quit);

    btip.set_tip(b1,"Press here to quit","A");
    b0.show();
    b1.show();
    bm3.show();
}

static void staticfunction(GdkEventKey* a) {
    printf("Staticfunction called! %p\n",a);
}

static void staticfunction_cb(GdkEventKey* a,void *) {
    printf("Staticfunction-cb called! %p\n",a);
}

Gtk_Main *mainwidget=0;

int
main(int argc, char *argv[])
{
    Gtk_Main myapp(&argc, &argv);
    mainwidget=&myapp;
    MyWin mywin(5);
    
    
    mywin.set_title("Notice!");

    mywin.show();
    
    // connecting to static function
    connect_to_function(mywin.keyPressed,&staticfunction); 
    connect_to_function(mywin.keyPressed,&staticfunction_cb,(void*)0);
    
    myapp.run();
    return 0;
}
